@@ -10,10 +10,6 @@
  *     Guido Tack, 2007-2012
  *     Gabriel Hjort Blindell, 2012
  *
- *  Last modified:
- *     $Date$ by $Author$
- *     $Revision$
- *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
  *     http://www.gecode.org
@@ -88,8 +84,8 @@ namespace std {
 
 namespace Gecode { namespace FlatZinc {
 
-  // Unitialized default random number generator
-  Rnd defrnd;
+  // Default random number generator
+  Rnd defrnd(0);
 
   /**
    * \brief Branching on the introduced variables
@@ -1038,10 +1034,11 @@ namespace Gecode { namespace FlatZinc {
   }
 
   void
-  FlatZincSpace::createBranchers(Printer&p, AST::Node* ann, int seed,
-                                 double decay,
+  FlatZincSpace::createBranchers(Printer&p, AST::Node* ann, FlatZincOptions& opt,
                                  bool ignoreUnknown,
                                  std::ostream& err) {
+    int seed = opt.seed();
+    double decay = opt.decay();
     Rnd rnd(static_cast<unsigned int>(seed));
     TieBreak<IntVarBranch> def_int_varsel = INT_VAR_AFC_SIZE_MAX(0.99);
     IntBoolVarBranch def_intbool_varsel = INTBOOL_VAR_AFC_SIZE_MAX(0.99);
@@ -1092,7 +1089,27 @@ namespace Gecode { namespace FlatZinc {
       }
 
       for (unsigned int i=0; i<flatAnn.size(); i++) {
-        if (flatAnn[i]->isCall("relax_and_reconstruct")) {
+        if (flatAnn[i]->isCall("restart_geometric")) {
+          AST::Call* call = flatAnn[i]->getCall("restart_geometric");
+          opt.restart(RM_GEOMETRIC);
+          AST::Array* args = call->getArgs(2);
+          opt.restart_base(args->a[0]->getFloat());
+          opt.restart_scale(args->a[1]->getInt());
+        } else if (flatAnn[i]->isCall("restart_luby")) {
+          AST::Call* call = flatAnn[i]->getCall("restart_luby");
+          opt.restart(RM_LUBY);
+          opt.restart_scale(call->args->getInt());
+        } else if (flatAnn[i]->isCall("restart_linear")) {
+          AST::Call* call = flatAnn[i]->getCall("restart_linear");
+          opt.restart(RM_LINEAR);
+          opt.restart_scale(call->args->getInt());
+        } else if (flatAnn[i]->isCall("restart_constant")) {
+          AST::Call* call = flatAnn[i]->getCall("restart_constant");
+          opt.restart(RM_CONSTANT);
+          opt.restart_scale(call->args->getInt());
+        } else if (flatAnn[i]->isCall("restart_none")) {
+          opt.restart(RM_NONE);
+        } else if (flatAnn[i]->isCall("relax_and_reconstruct")) {
           if (_lns != 0)
             throw FlatZinc::Error("FlatZinc",
             "Only one relax_and_reconstruct annotation allowed");
