@@ -6,10 +6,6 @@
  *  Copyright:
  *     Christian Schulte, 2010
  *
- *  Last modified:
- *     $Date$ by $Author$
- *     $Revision$
- *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
  *     http://www.gecode.org
@@ -509,9 +505,9 @@ namespace Gecode {
 
   void
   LinIntExpr::Node::fill(Home home, IntPropLevel ipl,
-                      Int::Linear::Term<Int::IntView>*& ti,
-                      Int::Linear::Term<Int::BoolView>*& tb,
-                      long long int m, long long int& d) const {
+                         Int::Linear::Term<Int::IntView>*& ti,
+                         Int::Linear::Term<Int::BoolView>*& tb,
+                         long long int m, long long int& d) const {
     switch (this->t) {
     case NT_CONST:
       Int::Limits::check(m*c,"MiniModel::LinIntExpr");
@@ -894,14 +890,9 @@ namespace Gecode {
   }
   LinIntExpr
   sum(const IntArgs& args) {
-    int i, sum = 0;
-    const int size = args.size();
-
-    for (i = 0 ; i < size ; ++i)
-    {
+    int sum = 0;
+    for (int i = 0; i<args.size(); i++)
       sum += args[i];
-    }
-
     return LinIntExpr(sum);
   }
 
